@@ -1,11 +1,12 @@
 """pipewire_python:
 Python controller, player and recorder via pipewire's commands"""
 
-__version__ = "0.0.7"
+__version__ = "0.0.82"
 
 import sys
 
 if sys.platform == "linux":
-    from pipewire_python.controller import *
+    # from pipewire_python.controller import *
+    pass
 else:
     raise NotImplementedError("By now, Pipewire only runs on linux.")
