@@ -13,7 +13,7 @@ audio_controller.set_config(rate=384000,
                             quality=4,
                             # Debug
                             verbose=True)
-audio_controller.Playback(audio_filename='docs/beers.wav',
+audio_controller.playback(audio_filename='docs/beers.wav',
                           # Debug
                           verbose=True)
 
@@ -28,7 +28,7 @@ audio_controller.Playback(audio_filename='docs/beers.wav',
 
 # normal way
 audio_controller = Controller(verbose=True)
-audio_controller.Record(audio_filename='docs/5sec_record.wav',
+audio_controller.record(audio_filename='docs/5sec_record.wav',
                         timeout_seconds=5,
                         # Debug
                         verbose=True)
